@@ -45,8 +45,8 @@ def propose_filename(collection: storage.BaseCollection) -> str:
 
 class ApplicationPartGet(ApplicationBase):
 
-    def _content_disposition_attachement(self, filename: str) -> str:
-        value = "attachement"
+    def _content_disposition_attachment(self, filename: str) -> str:
+        value = "attachment"
         try:
             encoded_filename = quote(filename, encoding=self._encoding)
         except UnicodeEncodeError:
@@ -66,6 +66,8 @@ class ApplicationPartGet(ApplicationBase):
         if path == "/.web" or path.startswith("/.web/"):
             # Redirect to sanitized path for all subpaths of /.web
             unsafe_path = environ.get("PATH_INFO", "")
+            if len(base_prefix) > 0:
+                unsafe_path = unsafe_path.removeprefix(base_prefix)
             if unsafe_path != path:
                 location = base_prefix + path
                 logger.info("Redirecting to sanitized path: %r ==> %r",
@@ -91,7 +93,7 @@ class ApplicationPartGet(ApplicationBase):
                     return (httputils.NOT_ALLOWED if limited_access else
                             httputils.DIRECTORY_LISTING)
                 content_type = xmlutils.MIMETYPES[item.tag]
-                content_disposition = self._content_disposition_attachement(
+                content_disposition = self._content_disposition_attachment(
                     propose_filename(item))
             elif limited_access:
                 return httputils.NOT_ALLOWED
